@@ -89,7 +89,7 @@ class DocumentAlert : public QObject
     Q_PROPERTY(QString title MEMBER m_title CONSTANT FINAL)
     Q_PROPERTY(QString body MEMBER m_body CONSTANT FINAL)
     Q_PROPERTY(uint level MEMBER m_level CONSTANT FINAL)
-    Q_PROPERTY(QStringList actionLabels READ actionLabels FINAL)
+    Q_PROPERTY(QStringList actionLabels READ actionLabels CONSTANT FINAL)
     
 public:
     enum LEVEL : uint { INFO_LEVEL = 0, WARNING_LEVEL = 1, DANGER_LEVEL = 2 };
@@ -253,6 +253,7 @@ class DocumentHandler : public QObject
     Q_PROPERTY(bool underline READ underline WRITE setUnderline NOTIFY underlineChanged)
     Q_PROPERTY(bool isRich READ getIsRich NOTIFY isRichChanged)
 
+    Q_PROPERTY(int lineCount READ lineCount NOTIFY lineCountChanged)
     Q_PROPERTY(int fontSize READ fontSize WRITE setFontSize NOTIFY fontSizeChanged)
     Q_PROPERTY(qreal tabSpace READ tabSpace WRITE setTabSpace NOTIFY tabSpaceChanged)
 
@@ -287,9 +288,6 @@ class DocumentHandler : public QObject
     
     Q_PROPERTY(bool findCaseSensitively MEMBER m_findCaseSensitively NOTIFY findCaseSensitivelyChanged)
 
-    
-//     Q_PROPERTY(int cursorYPos READ cursorYPos NOTIFY cursorYPosChanged)
-
 public:
     explicit DocumentHandler(QObject *parent = nullptr);
     ~DocumentHandler();
@@ -632,6 +630,8 @@ public slots:
      * @return
      */
     int lineHeight(const int &line);
+    
+    int lineCount();
 
     /**
      * @brief getCurrentLineIndex
@@ -639,7 +639,7 @@ public slots:
      */
     int getCurrentLineIndex();
     
-//     int cursorYPos() const;
+    int goToLine(const int &line);
 
     /**
      * @brief getLanguageNameList
@@ -678,6 +678,7 @@ signals:
     void underlineChanged();
     void isRichChanged();
 
+    void lineCountChanged();
     void fontSizeChanged();
     void tabSpaceChanged();
 
@@ -696,7 +697,7 @@ signals:
 
     void backgroundColorChanged();
 
-    void formatNameChanged() const;
+    void formatNameChanged();
 
     void modifiedChanged();
 
